#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.eno_cd5_interfaces.cd5_id import CD5ID
from pycatia.eno_cd5_interfaces.cd5_structure import CD5Structure
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class CD5Engine(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CD5Engine
                | 
                | Represents the ENOVIA V6 Integration Engine, that is to say the entry point to
                | the CATIA/ENOVIA V6 Integration.
                | 
                | It allows end user to realize the following operations : connection and disconnection to
                | ENOVIA V6 Integration, creation of ENOVIA V6 Integration IDs (CD5ID) and Structures (CD5Strcture),
                | and opening of the corresponding objects in different modes.
                | Note that all operations performed from this interface are the same as
                | operations available in the ENOVIA V6 menu in CATIA, unless most of them are
                | executed without panel.
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve the ENOVIA V6 Integration
                |       Engine.
                |
                |      Dim oCD5Engine As CD5Engine
                |      Set oCD5Engine = CATIA.GetItem("CD5Engine")
                |
                | See also:
                |     CD5ID, CD5Structure
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_engine = com_object

    @property
    def expand_mode(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExpandMode() As CATBSTR
                | 
                |     Returns (gets) or sets the value of the Open option "Expand Mode". The
                |     default value is set in the user's Preferences.
                | 
                |     Throws:
                | 
                |         -1641847650 : Connection to ENOVIA V6 is necessary to intialize this option.
                | 
                |     Example:
                | 
                |           The following example sets Expand Mode to LatestVersion, then
                |           displays it.
                |
                |          oCD5Engine.ExpandMode = "LatestVersion"
                |          MsgBox oCD5Engine.ExpandMode

        :rtype: str
        """

        return self.cd5_engine.ExpandMode

    @expand_mode.setter
    def expand_mode(self, value: str):
        """
        :param str value:
        """

        self.cd5_engine.ExpandMode = value

    @property
    def include_all_children(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IncludeAllChildren() As boolean
                | 
                |     Returns (gets) or sets the value of the Open option "Open With". The
                |     default value is False, means Required Children.
                | 
                |     Example:
                | 
                |           The following example sets Open With to All
                |           Children.
                |
                |          oCD5Engine.IncludeAllChildren = True

        :rtype: bool
        """

        return self.cd5_engine.IncludeAllChildren

    @include_all_children.setter
    def include_all_children(self, value: bool):
        """
        :param bool value:
        """

        self.cd5_engine.IncludeAllChildren = value

    @property
    def related_designs(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RelatedDesigns() As CATBSTR
                | 
                |     Returns (gets) or sets the value of the Open option "Related Designs". The
                |     default value is set in the user's Preferences.
                | 
                |     Throws:
                | 
                |         -1641847650 : Connection to ENOVIA V6 is necessary to intialize this option.
                | 
                |     Example:
                | 
                |           The following example sets Related Designs to Associated Drawings,
                |           then displays it.
                |
                |          oCD5Engine.RelatedDesigns = "Associated Drawings"
                |          MsgBox oCD5Engine.RelatedDesigns

        :rtype: str
        """

        return self.cd5_engine.RelatedDesigns

    @related_designs.setter
    def related_designs(self, value: str):
        """
        :param str value:
        """

        self.cd5_engine.RelatedDesigns = value

    def connect(self, i_user_name: str, i_user_password: str, i_security_context: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Connect(CATBSTR iUserName,
                | CATBSTR iUserPassword,
                | CATBSTR iSecurityContext)
                | 
                |     Connects to ENOVIA V6. It is equivalent to launch in CATIA the command
                |     ENOVIA V6/Connect and enter the User Name/Password/Security
                |     Context.
                | 
                |     Parameters:
                | 
                |         iUserName
                |             The Login name of the end user, who wants to connect to ENOVIA V6.
                |             
                |         iUserPassword
                |             The associated Password of this end user. 
                |         iSecurityContext
                |             The security context the end user wants to use (if empty, the API
                |             will first try to connect without security context then try again with the
                |             default one). 
                | 
                |     Throws:
                | 
                |         -1867244384 : The Document Location setting is incorrect.
                |         -1878815075 : Invalid Password.
                |         -1803748693 : Another user is already logged in.
                | 
                |     Example:
                | 
                |           The following example connects end user to ENOVIA V6 on CD5Engine
                |           oCD5Engine.
                |          The User Login is "xxx" and his associated Password
                |          "yyy".
                |
                |          Dim iUserName As CATBSTR
                |          iUserName = "xxx"
                |          Dim iUserPassword As CATBSTR
                |          iUserPassword = "yyy"
                |          oCD5Engine.Connect iUserName,iUserPassword,""

        :param str i_user_name:
        :param str i_user_password:
        :param str i_security_context:
        :rtype: None
        """
        return self.cd5_engine.Connect(i_user_name, i_user_password, i_security_context)

    def disconnect(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Disconnect()
                | 
                |     Disconnects from ENOVIA V6. It is equivalent to launch in CATIA the command
                |     ENOVIA V6/Disconnect.
                | 
                |     Example:
                | 
                |           The following example disconnects end user from ENOVIA V6 Integration
                |           on CD5Engine oCD5Engine.
                |
                |          oCD5Engine.Disconnect

        :rtype: None
        """
        return self.cd5_engine.Disconnect()

    def get_id_from_tnr(self, i_type: str, i_name: str, i_revision: str) -> CD5ID:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetIDFromTNR(CATBSTR iType,
                | CATBSTR iName,
                | CATBSTR iRevision) As CD5ID
                | 
                |     Creates a ENOVIA V6 Integration ID (CD5ID) from a Major Object thanks to
                |     its Type, Name and Revision.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of the ENOVIA V6 Object. 
                |         iName
                |             The name of the ENOVIA V6 Object. 
                |         iRevision
                |             The revision of the ENOVIA V6 Object. 
                | 
                |     Returns:
                |         The created CD5ID. 
                |     Example:
                | 
                |           The following example creates a CD5ID from the major object
                |           "MyProduct" of Type "CATProduct For Team" and Revision "---" on CD5Engine
                |           oCD5Engine.
                |
                |          Dim oCD5ID As CD5ID
                |          Set oCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "MyProduct", "---")

        :param str i_type:
        :param str i_name:
        :param str i_revision:
        :rtype: CD5ID
        """
        return CD5ID(self.cd5_engine.GetIDFromTNR(i_type, i_name, i_revision))

    def get_id_from_tnrv(self, i_type: str, i_name: str, i_revision: str, i_version: str) -> CD5ID:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetIDFromTNRV(CATBSTR iType,
                | CATBSTR iName,
                | CATBSTR iRevision,
                | CATBSTR iVersion) As CD5ID
                | 
                |     Creates a ENOVIA V6 Integration ID (CD5ID) from a Minor Object thanks to
                |     its Type, Name, Revision and Version.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of the ENOVIA V6 Object. 
                |         iName
                |             The name of the ENOVIA V6 Object. 
                |         iRevision
                |             The revision of the ENOVIA V6 Object. 
                |         iVersion
                |             The version of the ENOVIA V6 Object. 
                | 
                |     Returns:
                |         The created CD5ID. 
                |     Example:
                | 
                |           The following example creates a CD5ID from the minor object
                |           "MyProduct" of Type "CATProduct For Team", Revision "---" and Version "0" on
                |           CD5Engine oCD5Engine.
                |
                |          Dim oCD5ID As CD5ID
                |          Set oCD5ID = oCD5Engine.GetIDFromTNRV("CATProduct For Team", "MyProduct", "---", "0")

        :param str i_type:
        :param str i_name:
        :param str i_revision:
        :param str i_version:
        :rtype: CD5ID
        """
        return CD5ID(self.cd5_engine.GetIDFromTNRV(i_type, i_name, i_revision, i_version))

    def get_structure(self, i_cd5_id: CD5ID) -> CD5Structure:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStructure(CD5ID iCD5ID) As CD5Structure
                | 
                |     Creates a Structure from a ENOVIA V6 Object identified by its CD5ID, in the
                |     purpose of a future Partial Open.
                | 
                |     Parameters:
                | 
                |         iCD5ID
                |             The CD5ID of the ENOVIA V6 Object, candidate for a partial open.
                |
                |     Returns:
                |         The created CD5Structure. 
                |     Example:
                | 
                |           The following example creates a CD5Structure from the CD5ID of an
                |           object on CD5Engine oCD5Engine.
                |
                |          Dim iCD5ID As CD5ID
                |          Set iCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "MyProduct", "---")
                |          Dim oCD5Structure As CD5Structure
                |          Set oCD5Structure = oCD5Engine.GetStructure(iCD5ID)

        :param CD5ID i_cd5_id:
        :rtype: CD5Structure
        """
        return CD5Structure(self.cd5_engine.GetStructure(i_cd5_id.com_object))

    def interactive_open(self, i_cd5_id: CD5ID) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InteractiveOpen(CD5ID iCD5ID)
                | 
                |     Launches the Interactive ENOVIA V6 Open Command and performs the search
                |     with the input CD5ID.
                | 
                |     Parameters:
                | 
                |         iCD5ID
                |             The ENOVIA V6 ID of the Object to open in CATIA. 
                | 
                |     Throws:
                | 
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                | 
                |     Example:
                | 
                |           The following example launches the interactive ENOVIA V6 Open Command
                |           on CD5Engine oCD5Engine, with the following search
                |           criteria:
                |
                |             Type : "CATProduct For Team".
                |             Name : "MyProduct".
                |             Revision : "---".
                |
                |          Dim myCD5ID As CD5ID
                |          Set myCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "MyProduct", "---")
                |          oCD5Engine.InteractiveOpen(myCD5ID)

        :param CD5ID i_cd5_id:
        :rtype: None
        """
        return self.cd5_engine.InteractiveOpen(i_cd5_id.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'interactive_open'
        # # vba_code = """
        # # Public Function interactive_open(cd5_engine)
        # #     Dim iCD5ID (2)
        # #     cd5_engine.InteractiveOpen iCD5ID
        # #     interactive_open = iCD5ID
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_connected(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsConnected() As boolean
                | 
                |     Returns if end user is connected to ENOVIA V6 (True) or not
                |     (False).
                | 
                |     Example:
                | 
                |           The following example tests if end user is connected to ENOVIA V6
                |           Integration on CD5Engine oCD5Engine.
                |          A MsgBox with the connection status will appear to the end
                |          user.
                |          If end user is connected, the MsgBox will contain "Connected", else it
                |          will contain "Not Connected".
                |
                |          If oCD5Engine.IsConnected Then
                |            MsgBox "Connected"
                |          Else
                |            MsgBox "Not Connected"
                |          End If

        :rtype: bool
        """
        return self.cd5_engine.IsConnected()

    def open(self, i_cd5_id: CD5ID) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Open(CD5ID iCD5ID) As Document
                | 
                |     Opens a ENOVIA V6 Object in CATIA thanks to its previously created CD5ID,
                |     and returns the created Document.
                | 
                |     Parameters:
                | 
                |         iCD5ID
                |             The ENOVIA V6 ID of the Object to open in CATIA. 
                | 
                |     Returns:
                |         The created Document. 
                |     Throws:
                | 
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                |         -1871171370 : Failed to get details of design objects.
                | 
                |     Example:
                | 
                |           The following example opens an ENOVIA V6 Object in CATIA from its
                |           CD5ID on CD5Engine oCD5Engine.
                |
                |          Dim myCD5ID As CD5ID
                |          Set myCD5ID = oCD5Engine.GetIDFromTNRV("CATProduct For Team", "MyProduct", "---", "0")
                |          Dim oDocument As Document
                |          Set oDocument = oCD5Engine.Open(myCD5ID)

        :param CD5ID i_cd5_id:
        :rtype: Document
        """
        return Document(self.cd5_engine.Open(i_cd5_id.com_object))

    def partial_open(self, i_cd5_structure: CD5Structure) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func PartialOpen(CD5Structure iCD5Structure) As Document
                | 
                |     Opens partially a ENOVIA V6 Object in CATIA thanks to its previously
                |     created CD5Structure, and returns the created Document.
                | 
                |     Parameters:
                | 
                |         iCD5Structure
                |             The Structure of the Object to open in CATIA. 
                | 
                |     Returns:
                |         The created Document. 
                |     Throws:
                | 
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                |         -1871171370 : Failed to get details of design objects.
                | 
                |     Example:
                | 
                |           The following example opens partially the ENOVIA V6 Object
                |           "RootProduct" and its subproduct "DummyProduct" in CATIA on CD5Engine
                |           oCD5Engine.
                |
                |          Dim iRootCD5ID As CD5ID
                |          Set iRootCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "RootProduct", "---")
                |          Dim iSubCD5ID As CD5ID
                |          Set iSubCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "SubProduct", "---")
                |          Dim iCD5Structure As CD5Structure
                |          Set iCD5Structure = oCD5Engine.GetStructure(iRootCD5ID)
                |          iCD5Structure.Include(iDummyCD5ID)
                |          Dim oDocument As Document
                |          Set oDocument = oCD5Engine.PartialOpen(iCD5Structure)

        :param CD5Structure i_cd5_structure:
        :rtype: Document
        """
        return Document(self.cd5_engine.PartialOpen(i_cd5_structure.com_object))

    def __repr__(self):
        return f'CD5Engine(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class KweCorrectFunction(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KWECorrectFunction
                | 
                | Represents the Knowledge correct function.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.kwe_correct_function = com_object

    def check(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Check() As CATBaseDispatch
                | 
                |     Retrieves the check associtade to this correct function.
                | 
                |     Returns:
                |         oAssociatedCheck ExpertCheck associated to this correct function.

        :rtype: AnyObject
        """
        return self.kwe_correct_function.Check()

    def get_number_of_list_failed_elements(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfListFailedElements() As long
                | 
                |     Retrieves the number of roots of facts of the rule base.
                | 
                |     Returns:
                |         oArraySize Number of roots of facts.

        :rtype: int
        """
        return self.kwe_correct_function.GetNumberOfListFailedElements()

    def list_failed_elements(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListFailedElements(CATSafeArrayVariant
                | oListElementsOfTupleFailed)
                | 
                |     Returns the list of elements of current tuple failed.
                | 
                |     Parameters:
                | 
                |         oListElementsOfTupleFailed
                |             array of tuple elements.

        :param tuple o_list_elements_of_tuple_failed:
        :rtype: tuple
        """
        return self.kwe_correct_function.ListFailedElements()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_failed_elements'
        # # vba_code = """
        # # Public Function list_failed_elements(kwe_correct_function)
        # #     Dim oListElementsOfTupleFailed (2)
        # #     kwe_correct_function.ListFailedElements oListElementsOfTupleFailed
        # #     list_failed_elements = oListElementsOfTupleFailed
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'KweCorrectFunction(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.cat_mat_interfaces.material_families import MaterialFamilies
from pycatia.in_interfaces.document import Document


class MaterialDocument(Document):
    """
    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.AnyObject
            |                     InfInterfaces.Document
            |                         MaterialDocument
            |
            | Represents the Document object for materials.
            | When a MaterialDocument object is created, a MaterialFamily object
            | is created.
            | A Material object is also created inside this MaterialFamily
            | object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.material_document = com_object

    @property
    def families(self) -> MaterialFamilies:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Families() As MaterialFamilies (Read Only)
                |
                |     Returns the Family collection object from the current
                |     material document.

        :rtype: MaterialFamilies
        """
        return MaterialFamilies(self.material_document.Families)

    def __repr__(self):
        return f'MaterialDocument(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchematicExtension(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchematicExtension
                | 
                | Manage schematic extensions.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.schematic_extension = com_object

    def add_extension(
            self,
            i_app_obj_to_be_extended: AnyObject,
            i_extension_type: int,
            i_lgrr: SchListOfObjects
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddExtension(AnyObject iAppObjToBeExtended,
                | CatSchIDLExtensionType iExtensionType,
                | SchListOfObjects iLGRR)
                | 
                |     Adds a Schematic extension to an application object.
                | 
                |     Parameters:
                | 
                |         iAppObjToBeExtended
                |             The application object to be extended. 
                |         iExtensionType
                |             The extension type. 
                |         iLGRR
                |             If iLGRR is not NULL, then its members will be linked to the
                |             extension as graphics 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchematicExtension
                |          Dim objArg1 As AnyObject
                | 
                |          Dim objArg3 As SchListOfObjects
                |           ...
                |          objThisIntf.AddExtensionobjArg1,CatSchIDLExtensionType_Enum,objArg3

        :param AnyObject i_app_obj_to_be_extended:
        :param int i_extension_type: enum cat_sch_idl_extension_type
        :param SchListOfObjects i_lgrr:
        :rtype: None
        """
        return self.schematic_extension.AddExtension(
            i_app_obj_to_be_extended.com_object,
            i_extension_type,
            i_lgrr.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_extension'
        # # vba_code = """
        # # Public Function add_extension(schematic_extension)
        # #     Dim iAppObjToBeExtended (2)
        # #     schematic_extension.AddExtension iAppObjToBeExtended
        # #     add_extension = iAppObjToBeExtended
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_extension(self, i_app_extended_obj: AnyObject, i_extension_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveExtension(AnyObject iAppExtendedObj,
                | CatSchIDLExtensionType iExtensionType)
                | 
                |     Removes a Schematic extension to an application object.
                | 
                |     Parameters:
                | 
                |         iAppExtendedObj
                |             The application object to be have its extension removed.
                |             
                |         iExtensionType
                |             The extension type. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchematicExtension
                |          Dim objArg1 As AnyObject
                |           ...
                |          objThisIntf.RemoveExtensionobjArg1,CatSchIDLExtensionType_Enum

        :param AnyObject i_app_extended_obj:
        :param int i_extension_type: enum cat_sch_idl_extension_type
        :rtype: None
        """
        return self.schematic_extension.RemoveExtension(i_app_extended_obj.com_object, i_extension_type)

    def __repr__(self):
        return f'SchematicExtension(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.length import Length
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingHole(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingHole
                | 
                | Hole Feature in Machining domain.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_hole = com_object

    @property
    def depth(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Depth() As Length (Read Only)
                | 
                |     Returns the hole depth.
                | 
                |     Returns:
                |         oDepth A CATIALength object controlling the hole depth (@see
                |         CATIALength for more information)
                | 
                |         Example:
                |             The following example returns in holeDepth the depth of hole
                |             firstHole:
                | 
                |              Set holeDepth = firstHole.Depth

        :rtype: Length
        """

        return Length(self.manufacturing_hole.Depth)

    @property
    def diameter(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Diameter() As Length (Read Only)
                | 
                |     Returns the hole diameter.
                | 
                |     Returns:
                |         oDiameter A CATIALength object controlling the hole diameter (@see
                |         CATIALength for more information)
                | 
                |         Example:
                |             The following example returns in holeDiam the diameter of hole
                |             firstHole:
                | 
                |              Set holeDiam = firstHole.Diameter

        :rtype: Length
        """

        return Length(self.manufacturing_hole.Diameter)

    def get_direction(self, o_x: float, o_y: float, o_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDirection(double oX,
                | double oY,
                | double oZ)
                | 
                |     Returns the hole direction with absolute coordinates.
                | 
                |     Returns:
                |         3 doubles: X, Y, Z - direction coordinates
                | 
                |         Example:
                |             The following example returns in X, Y, Z the direction coordinates
                |             of hole firstHole:
                | 
                |              call firstHole.GetDirection(X,Y,Z)

        :param float o_x:
        :param float o_y:
        :param float o_z:
        :rtype: None
        """
        return self.manufacturing_hole.GetDirection(o_x, o_y, o_z)

    def get_origin(self, o_x: float, o_y: float, o_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOrigin(double oX,
                | double oY,
                | double oZ)
                | 
                |     Returns the origin point which the hole is anchored to.
                | 
                |     Returns:
                |         3 doubles: X, Y, Z - Hole origin point coordinates
                | 
                |         Example:
                |             The following example returns in X, Y, Z the origin coordinates of
                |             hole firstHole:
                | 
                |              call firstHole.GetOrigin(X,Y,Z)

        :param float o_x:
        :param float o_y:
        :param float o_z:
        :rtype: None
        """
        return self.manufacturing_hole.GetOrigin(o_x, o_y, o_z)

    def __repr__(self):
        return f'ManufacturingHole(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class GeneralSessionSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         GeneralSessionSettingAtt
                | 
                | Setting controller for the General property tab page.
                | Role: This interface is implemented by a component which represents the
                | controller of the general settings.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.general_session_setting_att = com_object

    @property
    def auto_save(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AutoSave() As CATGenDataSave
                | 
                |     Returns the data save parameter.

        :return: enum cat_gen_data_save
        :rtype: int
        """

        return self.general_session_setting_att.AutoSave

    @auto_save.setter
    def auto_save(self, value: int):
        """
        :param int value: enum cat_gen_data_save
        """

        self.general_session_setting_att.AutoSave = value

    @property
    def conferencing(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Conferencing() As CATGenConferencing
                | 
                |     Returns the conference driver parameter.

        :return: enum cat_gen_conferencing
        :rtype: int
        """

        return self.general_session_setting_att.Conferencing

    @conferencing.setter
    def conferencing(self, value: int):
        """
        :param int value: enum cat_gen_conferencing
        """

        self.general_session_setting_att.Conferencing = value

    @property
    def drag_drop(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DragDrop() As boolean
                | 
                |     Returns the drag & drop parameter.

        :rtype: bool
        """

        return self.general_session_setting_att.DragDrop

    @drag_drop.setter
    def drag_drop(self, value: bool):
        """
        :param bool value:
        """

        self.general_session_setting_att.DragDrop = value

    @property
    def ref_doc(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RefDoc() As boolean
                | 
                |     Returns the referenced documents parameter.

        :rtype: bool
        """

        return self.general_session_setting_att.RefDoc

    @ref_doc.setter
    def ref_doc(self, value: bool):
        """
        :param bool value:
        """

        self.general_session_setting_att.RefDoc = value

    @property
    def time_roll(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TimeRoll() As long
                | 
                |     Returns the data save parameter (in milliseconds).

        :rtype: int
        """

        return self.general_session_setting_att.TimeRoll

    @time_roll.setter
    def time_roll(self, value: int):
        """
        :param int value:
        """

        self.general_session_setting_att.TimeRoll = value

    @property
    def ui_style(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property UIStyle() As CATGenUIStyle
                | 
                |     Returns the user interface style parameter.

        :return: enum cat_gen_ui_style
        :rtype: int
        """

        return self.general_session_setting_att.UIStyle

    @ui_style.setter
    def ui_style(self, value: int):
        """
        :param int value: enum cat_gen_ui_style
        """

        self.general_session_setting_att.UIStyle = value

    def get_auto_save_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetAutoSaveInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the data save
                |     parameter.
                |     Role:Retrieves the state of the data save parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.general_session_setting_att.GetAutoSaveInfo(io_admin_level, io_locked)

    def get_conferencing_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetConferencingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the conference driver
                |     parameter.
                |     Role:Retrieves the state of the conference driver parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.general_session_setting_att.GetConferencingInfo(io_admin_level, io_locked)

    def get_drag_drop_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDragDropInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the drag & drop
                |     parameter.
                |     Role:Retrieves the state of the drag & drop parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.general_session_setting_att.GetDragDropInfo(io_admin_level, io_locked)

    def get_ref_doc_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetRefDocInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the referenced documents
                |     parameter.
                |     Role:Retrieves the state of the referenced documents parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.general_session_setting_att.GetRefDocInfo(io_admin_level, io_locked)

    def get_ui_style_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetUIStyleInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the user interface style
                |     parameter.
                |     Role:Retrieves the state of the user interface style parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.general_session_setting_att.GetUIStyleInfo(io_admin_level, io_locked)

    def set_auto_save_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAutoSaveLock(boolean iLocked)
                | 
                |     Locks or unlocks the data save parameter.
                |     Role:Locks or unlocks the data save parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.general_session_setting_att.SetAutoSaveLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auto_save_lock'
        # # vba_code = """
        # # Public Function set_auto_save_lock(general_session_setting_att)
        # #     Dim iLocked (2)
        # #     general_session_setting_att.SetAutoSaveLock iLocked
        # #     set_auto_save_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_conferencing_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetConferencingLock(boolean iLocked)
                | 
                |     Locks or unlocks the conference driver parameter.
                |     Role:Locks or unlocks the conference driver parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.general_session_setting_att.SetConferencingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_conferencing_lock'
        # # vba_code = """
        # # Public Function set_conferencing_lock(general_session_setting_att)
        # #     Dim iLocked (2)
        # #     general_session_setting_att.SetConferencingLock iLocked
        # #     set_conferencing_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_drag_drop_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDragDropLock(boolean iLocked)
                | 
                |     Locks or unlocks the drag & drop parameter.
                |     Role:Locks or unlocks the drag & drop parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.general_session_setting_att.SetDragDropLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_drag_drop_lock'
        # # vba_code = """
        # # Public Function set_drag_drop_lock(general_session_setting_att)
        # #     Dim iLocked (2)
        # #     general_session_setting_att.SetDragDropLock iLocked
        # #     set_drag_drop_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ref_doc_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRefDocLock(boolean iLocked)
                | 
                |     Locks or unlocks the referenced documents parameter.
                |     Role:Locks or unlocks the referenced documents parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.general_session_setting_att.SetRefDocLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ref_doc_lock'
        # # vba_code = """
        # # Public Function set_ref_doc_lock(general_session_setting_att)
        # #     Dim iLocked (2)
        # #     general_session_setting_att.SetRefDocLock iLocked
        # #     set_ref_doc_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ui_style_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetUIStyleLock(boolean iLocked)
                | 
                |     Locks or unlocks the user interface style parameter.
                |     Role:Locks or unlocks the user interface style parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.general_session_setting_att.SetUIStyleLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ui_style_lock'
        # # vba_code = """
        # # Public Function set_ui_style_lock(general_session_setting_att)
        # #     Dim iLocked (2)
        # #     general_session_setting_att.SetUIStyleLock iLocked
        # #     set_ui_style_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'GeneralSessionSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchGRRRoute2(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchGRRRoute2
                | 
                | Manage the graphical representation of a schematic route.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_grr_route2 = com_object

    def get_reshape_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetReshapeMode(CatSchIDLGRRRouteReshapeMode
                | oReshapeMode)
                | 
                |     Get the reshape mode.
                | 
                |     Parameters:
                | 
                |         oReshapeMode
                |             Whether or not the route shape is fixed for the purpose of reshaping the route.
                |             = SchFixedShapeOff : no restriction on how to reshape the route.
                |             = SchFixedShapeOn : reshape only the route's extremity (the segment directly connected to
                |             the object that's being moved).
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRRoute2
                | 
                |           ...
                |          objThisIntf.GetReshapeModeCatSchIDLGRRRouteReshapeMode_Enum

        :return: enum cat_sch_idlgrr_route_reshape_mode
        :rtype: None
        """
        return self.sch_grr_route2.GetReshapeMode()

    def set_reshape_mode(self, i_reshape_mode: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetReshapeMode(CatSchIDLGRRRouteReshapeMode
                | iReshapeMode)
                | 
                |     Set the reshape mode.
                | 
                |     Parameters:
                | 
                |         iReshapeMode
                |             Whether or not the route shape is fixed for the purpose of reshaping the route.
                |             = SchFixedShapeOff : no restriction on how to reshape the route.
                |             = SchFixedShapeOn : reshape only the route's extremity (the segment directly connected
                |               to the object that's being moved).
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRRoute2
                | 
                |           ...
                |          objThisIntf.SetReshapeModeCatSchIDLGRRRouteReshapeMode_Enum

        :param int i_reshape_mode: enum cat_sch_idlgrr_route_reshape_mode
        :rtype: None
        """
        return self.sch_grr_route2.SetReshapeMode(i_reshape_mode)

    def __repr__(self):
        return f'SchGRRRoute2(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingActivitySyntax(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingActivitySyntax
                | 
                | This interface offers services to manage PP words of activity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_activity_syntax = com_object

    def reset_pp_word_syntax(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetPPWORDSyntax()
                | 
                |     Resets the PP words syntax.
                | 
                |     Returns:
                |         S_OK when the method succeeds, and E_FAIL otherwise

        :rtype: None
        """
        return self.manufacturing_activity_syntax.ResetPPWORDSyntax()

    def set_pp_word_syntax(self, i_ppwords: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPPWORDSyntax(CATBSTR iPPWORDs)
                | 
                |     Sets the PP words syntax.
                | 
                |     Returns:
                |         S_OK when the method succeeds, and E_FAIL otherwise 
                |     Parameters:
                | 
                |         iPPWORDs
                |             The user PP words syntax to set

        :param str i_ppwords:
        :rtype: None
        """
        return self.manufacturing_activity_syntax.SetPPWORDSyntax(i_ppwords)

    def __repr__(self):
        return f'ManufacturingActivitySyntax(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.system_interfaces.any_object import AnyObject


class SchGRRRouteEllipse(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchGRRRouteEllipse
                | 
                | Manage the graphical representation of a schematic route.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_grr_route_ellipse = com_object

    def get_seed_point(self, o_db2_xy: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSeedPoint(SchListOfDoubles oDb2XY)
                | 
                |     Get the seed point of the route graphic ellipse.
                | 
                |     Parameters:
                | 
                |         oDb2XY
                |             X-Y coordinates of the seed point for the ellipse.
                |             
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRRouteEllipse
                |          Dim objArg1 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetSeedPointobjArg1

        :param SchListOfDoubles o_db2_xy:
        :rtype: None
        """
        return self.sch_grr_route_ellipse.GetSeedPoint(o_db2_xy.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_seed_point'
        # # vba_code = """
        # # Public Function get_seed_point(sch_grr_route_ellipse)
        # #     Dim oDb2XY (2)
        # #     sch_grr_route_ellipse.GetSeedPoint oDb2XY
        # #     get_seed_point = oDb2XY
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def has_seed_point(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub HasSeedPoint(boolean oBYes)
                | 
                |     Check to see if the Seed point has been set.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             TRUE if the seed point has been initialized. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRRouteEllipse
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.HasSeedPointbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_grr_route_ellipse.HasSeedPoint(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'has_seed_point'
        # # vba_code = """
        # # Public Function has_seed_point(sch_grr_route_ellipse)
        # #     Dim oBYes (2)
        # #     sch_grr_route_ellipse.HasSeedPoint oBYes
        # #     has_seed_point = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_seed_point(self, i_db2_xy: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSeedPoint(CATSafeArrayVariant iDb2XY)
                | 
                |     Set the seed point of the route graphic ellipse.
                | 
                |     Parameters:
                | 
                |         iDb2EndPt
                |             X-Y coordinates of the seed point for the ellipse.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchGRRRouteEllipse
                |          Dim dbVar1(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetSeedPointdbVar1

        :param tuple i_db2_xy:
        :rtype: tuple
        """
        return self.sch_grr_route_ellipse.SetSeedPoint(i_db2_xy)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_seed_point'
        # # vba_code = """
        # # Public Function set_seed_point(sch_grr_route_ellipse)
        # #     Dim iDb2XY (2)
        # #     sch_grr_route_ellipse.SetSeedPoint iDb2XY
        # #     set_seed_point = iDb2XY
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchGRRRouteEllipse(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.plane import Plane
from pycatia.in_interfaces.reference import Reference


class HybridShapePlane1Line1Pt(Plane):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Plane
                |                             HybridShapePlane1Line1Pt
                | 
                | Represents plane feature defined by a line and a point.
                | Role: Allows to access data of the plane feature passing though one line and
                | one point
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_plane1_line1_pt = com_object

    @property
    def line(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Line() As Reference
                | 
                |     Returns or sets the passing line.
                | 
                |     Parameters:
                | 
                |         oLine
                |             Line. 
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane1_line1_pt.Line)

    @line.setter
    def line(self, reference_line: Reference):
        """
        :param Reference reference_line:
        """

        self.hybrid_shape_plane1_line1_pt.Line = reference_line

    @property
    def point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Point() As Reference
                | 
                |     Return or sets the passing point.
                | 
                |     Parameters:
                | 
                |         oPoint
                |             Point. 
                | 
                |     See also:
                |         Reference 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane1_line1_pt.Point)

    @point.setter
    def point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_plane1_line1_pt.Point = reference_point.com_object

    def __repr__(self):
        return f'HybridShapePlane1Line1Pt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class Tag(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Tag
                | 
                | Interface representing a Tag.
                | 
                | Role: This interface is used to work with Tag.
                | The following code snippet can be used to obtain a Tag from a selected
                | Product
                | 
                |   Set ParentObject = CATIA.ActiveDocument.Selection.FindObject("CATIAProduct")	
                |   Set objTag = ParentObject.GetTechnologicalObject("Tag")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tag = com_object

    def get_name(self, o_tag_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetName(CATBSTR oTagName)
                | 
                |     Retreives name of the Tag.
                | 
                |     Parameters:
                | 
                |         oTagName
                |             Name of the Tag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             . 
                | 
                |     Example:
                | 
                |               
                | 
                |              Dim objTag As Tag
                |              ...
                |              Dim Name as String
                |              objTag.GetName Name

        :param str o_tag_name:
        :rtype: None
        """
        return self.tag.GetName(o_tag_name)

    def get_type(self, o_frame_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetType(CATBSTR oFrameName)
                | 
                |     Get Frame Type of the Tag by Name.
                | 
                |     Parameters:
                | 
                |         oFrameName
                |             Name of the Required Frame.
                |             Legal values : Returned tag frame by Name is either :
                | 
                |             Manufacturing,
                |             Design,
                |             Tool,
                |             Base,
                |             Custom
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             . 
                | 
                |     Example:
                | 
                |               
                | 
                |              Dim objTag As Tag
                |              ...
                |              Dim FrameType as String
                |              objTag.GetType FrameType

        :param str o_frame_name:
        :rtype: None
        """
        return self.tag.GetType(o_frame_name)

    def get_xyz(self, io_xyz: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetXYZ(CATSafeArrayVariant ioXYZ)
                | 
                |     Gets the Position(X, Y, Z) of the Tag.
                | 
                |     Parameters:
                | 
                |         ioXYZ
                |             The underlying Tag position. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             . 
                | 
                |     Example:
                | 
                |               
                | 
                |              Dim objTag As Tag
                |              ...
                |              Dim List(3)
                |              objTag.GetXYZ List

        :param tuple io_xyz:
        :rtype: None
        """
        return self.tag.GetXYZ(io_xyz)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_xyz'
        # # vba_code = """
        # # Public Function get_xyz(tag)
        # #     Dim ioXYZ (2)
        # #     tag.GetXYZ ioXYZ
        # #     get_xyz = ioXYZ
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_ypr(self, io_ypr: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetYPR(CATSafeArrayVariant ioYPR)
                | 
                |     Gets the Orientation (Y, P, R) of the Tag.
                | 
                |     Parameters:
                | 
                |         ioYPR
                |             The underlying Tag orientation. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             . 
                | 
                |     Example:
                | 
                |               
                | 
                |              Dim objTag As Tag
                |              ...
                |              Dim List(3)
                |              objTag.GetYPR List

        :param tuple io_ypr:
        :rtype: None
        """
        return self.tag.GetYPR(io_ypr)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_ypr'
        # # vba_code = """
        # # Public Function get_ypr(tag)
        # #     Dim ioYPR (2)
        # #     tag.GetYPR ioYPR
        # #     get_ypr = ioYPR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_name(self, i_tag_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetName(CATBSTR iTagName)
                | 
                |     Sets name of the Tag.
                | 
                |     Parameters:
                | 
                |         iTagName
                |             Name of the Tag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             . 
                | 
                |     Example:
                | 
                |               
                | 
                |              Dim objTag As Tag
                |              ...
                |              objTag.SetName("My_Tag")

        :param str i_tag_name:
        :rtype: None
        """
        return self.tag.SetName(i_tag_name)

    def set_type(self, i_frame_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetType(CATBSTR iFrameName)
                | 
                |     Sets Frame Type of the Tag by Name.
                | 
                |     Parameters:
                | 
                |         iFrameName
                |             Name of the Required Frame.
                |             Legal values : Tag frame can be set by name to either :
                | 
                |             Manufacturing,
                |             Design,
                |             Tool,
                |             Base,
                |             Custom
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             . 
                | 
                |     Example:
                | 
                |               
                | 
                |              Dim objTag As Tag
                |              ...
                |              objTag.SetType("Design")

        :param str i_frame_name:
        :rtype: None
        """
        return self.tag.SetType(i_frame_name)

    def set_xyz(self, i_x: float, i_y: float, i_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetXYZ(double iX,
                | double iY,
                | double iZ)
                | 
                |     Sets the Position(X, Y, Z) of the Tag.
                | 
                |     Parameters:
                | 
                |         iX
                |             The X value of the position 
                |         iY
                |             The Y value of the position 
                |         iZ
                |             The Z value of the position 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             . 
                | 
                |     Example:
                | 
                |               
                | 
                |              Dim objTag As Tag
                |              ...
                |              objTag.SetXYZ 2800.0, 1800.0, 800.0

        :param float i_x:
        :param float i_y:
        :param float i_z:
        :rtype: None
        """
        return self.tag.SetXYZ(i_x, i_y, i_z)

    def set_ypr(self, i_y: float, i_p: float, i_r: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetYPR(double iY,
                | double iP,
                | double iR)
                | 
                |     Sets the Orientation (Y, P, R) of the Tag.
                | 
                |     Parameters:
                | 
                |         iY
                |             The yaw value of the oreintation 
                |         iP
                |             The pitch value of the orientation 
                |         iR
                |             The roll value of the orientation 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             . 
                | 
                |     Example:
                | 
                |               
                | 
                |              Dim objTag As Tag
                |              ...
                |              objTag.SetYPR 1.4, 0.5, 3.14

        :param float i_y:
        :param float i_p:
        :param float i_r:
        :rtype: None
        """
        return self.tag.SetYPR(i_y, i_p, i_r)

    def __repr__(self):
        return f'Tag(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.workbench import Workbench
from pycatia.structure_interfaces.str_compute_services import StrComputeServices


class StrWorkbench(Workbench):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         StrWorkbench
                | 
                | Represents the structure workbench object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_workbench = com_object

    @property
    def str_compute_services(self) -> StrComputeServices:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StrComputeServices() As StrComputeServices (Read
                | Only)
                | 
                |     Returns the compute services object. It allows you to calculate some
                |     properties on the structure objects.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim services As StrComputeServices
                |          Set services = workbench_1.StrComputeServices

        :rtype: StrComputeServices
        """

        return StrComputeServices(self.str_workbench.StrComputeServices)

    def __repr__(self):
        return f'StrWorkbench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.analysis_interfaces.analysis_entities import AnalysisEntities
from pycatia.analysis_interfaces.analysis_supports import AnalysisSupports
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant

if TYPE_CHECKING:
    from pycatia.analysis_interfaces.basic_components import BasicComponents


class BasicComponent(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     BasicComponent
                | 
                | Interface designed to manage Analysis Basic Components.
                | 
                | A Basic Component is the low level of physical descriptive data. It is a
                | "brick" dedicated to build the Analysis Entity or an Analysis Set
                | .
                | 
                | A Basic Components can contain several Blocks. A Block is identified by a
                | label. It contains entity data of the same type, organized in superimposed
                | tables.
                | 
                | To create Analysis Entities with a complex structure, we have also created a
                | particular Basic Component dedicated to encapsulate other Basic
                | Components.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.basic_component = com_object

    @property
    def analysis_supports(self) -> AnalysisSupports:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisSupports() As AnalysisSupports (Read Only)
                | 
                |     Returns the list of Analysis Supports. The support defines the area on
                |     which the analysis is applied on.

        :rtype: AnalysisSupports
        """

        return AnalysisSupports(self.basic_component.AnalysisSupports)

    @property
    def basic_components(self) -> 'BasicComponents':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BasicComponents() As BasicComponents (Read Only)
                | 
                |     Returns the collection of Basic Components agregated by the basic
                |     component. It can be (scalar value, vector, tensor,...). Depending on the type
                |     of the Basic component, the collection can be empty.
                | 
                |     Example:
                | 
                |           This example retrieves Basic components collection 
                | 
                |          
                | 
                |          Dim MyBasicComp As BasicComponent
                |          Dim myBasicComponents As BasicComponents
                |          Set myBasicComponents = MyBasicComp.BasicComponents

        :rtype: BasicComponents
        """
        from pycatia.analysis_interfaces.basic_components import BasicComponents
        return BasicComponents(self.basic_component.BasicComponents)

    @property
    def entities(self) -> AnalysisEntities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Entities() As AnalysisEntities (Read Only)
                | 
                |     Returns the collection of Entities agregated by the basic component.
                |     Depending on the type of the Basic component,the collection can be
                |     empty.
                | 
                |     Example:
                | 
                |           This example retrieves Basic components collection 
                | 
                |          
                | 
                |          Dim MyBasicComp As BasicComponent
                |          Dim myEntities AnalysisEntities
                |          Set myEntities = MyBasicComp.AnalysisEntities

        :rtype: AnalysisEntities
        """

        return AnalysisEntities(self.basic_component.Entities)

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the Basic Component.
                | 
                |     Returns:
                |         The string that represent the Basic Component type.

        :rtype: str
        """

        return self.basic_component.Type

    def add_support_from_product(self, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromProduct(Product iProduct,
                | Reference iSupport)
                | 
                |     Creates a new support and add it to the description of the basic
                |     component.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             the CATIA Product that represent the object to
                |             linked.
                |         iSupport
                |             the CATIA Reference that represent the object to
                |             linked.
                | 
                |     See also:
                |         Reference, Product

        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.basic_component.AddSupportFromProduct(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_product'
        # # vba_code = """
        # # Public Function add_support_from_product(basic_component)
        # #     Dim iProduct (2)
        # #     basic_component.AddSupportFromProduct iProduct
        # #     add_support_from_product = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Creates a new support and add it to the description of the Basic
                |     Component.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             the CATIA Product that represent the object to
                |             linked.
                |         iPublication
                |             the CATIA Publication that represent the object to
                |             linked.
                | 
                |     See also:
                |         Publication, Product

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.basic_component.AddSupportFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(basic_component)
        # #     Dim iProduct (2)
        # #     basic_component.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_reference: Reference, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Reference iReference,
                | Reference iSupport)
                | 
                |     Creates a new support and add it to the description of the basic
                |     component.
                | 
                |     Parameters:
                | 
                |         iReference
                |             the CATIA Reference that represent the object to
                |             linked.
                |         iSupport
                |             the CATIA Reference that represent the object to
                |             linked.
                | 
                |     See also:
                |         Reference, Product

        :param Reference i_reference:
        :param Reference i_support:
        :rtype: None
        """
        return self.basic_component.AddSupportFromReference(i_reference.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(basic_component)
        # #     Dim iReference (2)
        # #     basic_component.AddSupportFromReference iReference
        # #     add_support_from_reference = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_columns_number(self, i_label: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetColumnsNumber(CATBSTR iLabel) As long
                | 
                |     Return one of the dimensions information of the Basic Component
                |     structure.
                | 
                |     Parameters:
                | 
                |         oColumnsNumber
                |             = Number of Columns.

        :param str i_label:
        :rtype: int
        """
        return self.basic_component.GetColumnsNumber(i_label)

    def get_layers_number(self, i_label: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLayersNumber(CATBSTR iLabel) As long
                | 
                |     Return one of the dimensions information of the Basic Component
                |     structure.
                | 
                |     Parameters:
                | 
                |         oLayersNumber
                |             = Number of Layers.

        :param str i_label:
        :rtype: int
        """
        return self.basic_component.GetLayersNumber(i_label)

    def get_lines_number(self, i_label: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLinesNumber(CATBSTR iLabel) As long
                | 
                |     Return one of the dimensions information of the Basic Component
                |     structure.
                | 
                |     Parameters:
                | 
                |         oLinesNumber
                |             = Number of lines.

        :param str i_label:
        :rtype: int
        """
        return self.basic_component.GetLinesNumber(i_label)

    def get_value(self, i_label: str, i_line_index: int, i_column_index: int, i_layer_index: int) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetValue(CATBSTR iLabel,
                | long iLineIndex,
                | long iColumnIndex,
                | long iLayerIndex) As CATVariant
                | 
                |     Return the value corresponding to the given coordinates.
                | 
                |     Parameters:
                | 
                |         iLabel
                |             = Label of the block containing the value.
                |         iLineIndex
                |             = line index of the value.
                |         iColumnIndex
                |             = column index of the value.
                |         iLayerIndex
                |             = layer index of the value.
                |             If the the component has a single value, set these 3 parameters to
                |             0.

        :param str i_label:
        :param int i_line_index:
        :param int i_column_index:
        :param int i_layer_index:
        :rtype: cat_variant
        """
        return self.basic_component.GetValue(i_label, i_line_index, i_column_index, i_layer_index)

    def set_dimensions(self, i_line_count: int, i_column_count: int, i_layer_count: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDimensions(long iLineCount,
                | long iColumnCount,
                | long iLayerCount)
                | 
                |     Sets the dimensions of the basic component.
                | 
                |     Parameters:
                | 
                |         iLineCount
                |             Number of lines.
                |         iColumnCount
                |             Number of columns.
                |         iLayerCount
                |             Number of layers.

        :param int i_line_count:
        :param int i_column_count:
        :param int i_layer_count:
        :rtype: None
        """
        return self.basic_component.SetDimensions(i_line_count, i_column_count, i_layer_count)

    def set_reference(
            self,
            i_label: str,
            i_line_index: int,
            i_column_index: int,
            i_layer_index: int,
            i_value: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetReference(CATBSTR iLabel,
                | long iLineIndex,
                | long iColumnIndex,
                | long iLayerIndex,
                | Reference iValue)
                | 
                |     Sets the reference corresponding to the given component.
                | 
                |     Parameters:
                | 
                |         iLabel
                |             The label of the block containing the value.
                |         iLineIndex
                |             The line index of the value.
                |         iColumnIndex
                |             The column index of the value.
                |         iLayerIndex
                |             The layer index of the value.
                |             If the the component has a single value, assign 0 to the 3
                |             parameters.

        :param str i_label:
        :param int i_line_index:
        :param int i_column_index:
        :param int i_layer_index:
        :param Reference i_value:
        :rtype: None
        """
        return self.basic_component.SetReference(
            i_label,
            i_line_index,
            i_column_index,
            i_layer_index,
            i_value.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_reference'
        # # vba_code = """
        # # Public Function set_reference(basic_component)
        # #     Dim iLabel (2)
        # #     basic_component.SetReference iLabel
        # #     set_reference = iLabel
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_value(
            self,
            i_label: str,
            i_line_index: int,
            i_column_index: int,
            i_layer_index: int,
            i_value: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetValue(CATBSTR iLabel,
                | long iLineIndex,
                | long iColumnIndex,
                | long iLayerIndex,
                | CATVariant iValue)
                | 
                |     Set the value corresponding to the given coordinates.
                | 
                |     Parameters:
                | 
                |         iLabel
                |             = Label of the block containing the value.
                |         iLineIndex
                |             = line index of the value.
                |         iColumnIndex
                |             = column index of the value.
                |         iLayerIndex
                |             = layer index of the value.
                |             If the the component has a single value, set these 3 parameters to
                |             0.

        :param str i_label:
        :param int i_line_index:
        :param int i_column_index:
        :param int i_layer_index:
        :param cat_variant i_value:
        :rtype: None
        """
        return self.basic_component.SetValue(
            i_label,
            i_line_index,
            i_column_index,
            i_layer_index,
            i_value
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_value'
        # # vba_code = """
        # # Public Function set_value(basic_component)
        # #     Dim iLabel (2)
        # #     basic_component.SetValue iLabel
        # #     set_value = iLabel
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'BasicComponent(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_opening import SFMOpening
from pycatia.cat_str_functional_interfaces.sfm_references import SFMReferences
from pycatia.cat_str_functional_interfaces.sfm_standard_contour_parameters import SFMStandardContourParameters
from pycatia.cat_str_functional_interfaces.sfm_standard_opening import SFMStandardOpening
from pycatia.cat_str_functional_interfaces.sfm_standard_pos_strategy_parameters import SFMStandardPosStrategyParameters
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.factory import Factory
from pycatia.mec_mod_interfaces.part import Part
from pycatia.system_interfaces.any_object import AnyObject


class SFMFunctionFactory(Factory):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Factory
                |                         SfmFunctionFactory
                | 
                | Gets the Function Factory.
                | 
                | Example:
                |     This Example Retrieves SfmFunctionFactory from Part.
                | 
                |      Set part1 = partDocument1.Part
                |      Dim Factory As SfmFunctionFactory
                |      Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_function_factory = com_object

    @property
    def sfm_references(self) -> SFMReferences:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SfmReferences() As SfmReferences (Read Only)
                | 
                |     Gets the list of Sfm References. Use it to prepare a list of U & V
                |     References for Standard Opening.
                | 
                |     Example:
                |         This example populates a list for U References. Use the Add Method to
                |         add a reference to the list.
                | 
                |          Dim Factory As SfmFunctionFactory
                |          Set Factory = Part1.GetCustomerFactory("SfmFunctionFactory") 
                |          Dim Uref1 As Reference
                |          Set Uref1 = Part1.FindObjectByName("CROSS.95")
                |          Dim UrefList As SfmReferences
                |          Set UrefList = Factory.SfmReferences
                |          UrefList.Add Uref1

        :rtype: SFMReferences
        """

        return SFMReferences(self.sfm_function_factory.SfmReferences)

    def create_opening(
            self,
            i_category: str,
            i_mode: int,
            i_intersecting_element: Reference,
            i_sfm_object: Reference
    ) -> SFMOpening:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateOpening(CATBSTR iCategory,
                | long iMode,
                | Reference iIntersectingElement,
                | Reference iSfmObject) As SfmOpening
                | 
                |     Creates Opening on SuperPlate or a Profile using a sketch or
                |     3DObject.
                | 
                |     Parameters:
                | 
                |         iCategory
                |             [in] Category of Opening 
                |         iMode
                |             [in] Enter 1: To Create Opening Using Sketch Mode Enter 0: To
                |             Create Opening Using 3D Object Mode 
                |         iIntersectingElement
                |             [in] Sketch or 3D Object 
                |         iSfmObject
                |             [in] Object on which Opening is to be created. 
                |         oOpening
                |             [out] Created Opening 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example Creates Opening on the Plate using Sketch Mode. The
                |             Factory is retrieved from the Part.
                | 
                |               'Retrieve the Factory
                |               Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
                |               Set sketch = part1.FindObjectByName("Sketch.1")
                |               Set sketchref = part1.CreateReferenceFromObject(sketch)
                |               Set plate = part1.FindObjectByName("Deck_117")
                |               Set plateref = part1.CreateReferenceFromObject(plate)
                |               'Create Opening
                |               Dim OpeningRes as SfmOpening
                |               Set OpeningRes = Factory.CreateOpening("FunctionalOpening",1,sketchref, plateref)

        :param str i_category:
        :param int i_mode:
        :param Reference i_intersecting_element:
        :param Reference i_sfm_object:
        :rtype: SFMOpening
        """
        return SFMOpening(
            self.sfm_function_factory.CreateOpening(
                i_category,
                i_mode,
                i_intersecting_element.com_object,
                i_sfm_object.com_object
            )
        )

    def create_standard_opening(
            self,
            i_category: str,
            i_contour_name: str,
            i_list_contour_params: SFMStandardContourParameters,
            i_pos_strategy_name: str,
            i_position_strategy_parms: SFMStandardPosStrategyParameters,
            isp_target_sfm_object: Reference
    ) -> SFMStandardOpening:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateStandardOpening(CATBSTR iCategory,
                | CATBSTR iContourName,
                | SfmStandardContourParameters iListContourParams,
                | CATBSTR iPosStrategyName,
                | SfmStandardPosStrategyParameters iPositionStrategyParms,
                | Reference ispTargetSfmObject) As SfmStandardOpening
                | 
                |     Creates a StandardOpening on SuperPlate.
                | 
                |     Parameters:
                | 
                |         iCategory
                |             [in] Category of Opening 
                |         iContourName
                |             [in] Name of the Contour. To Get List of Available contour names
                |             ,please see CATIASfmOpeningContoursMgr 
                |         iListContourParams
                |             [in] List of Conotour Parameters for selected Contour For Setting
                |             these parameters,Please see CATIASfmOpeningContoursMgr
                |             
                |         iPosStrategyName
                |             [in] Name of the Position Strategy. Legal
                |             Values:"CATSfmPosOffsetOffset",
                |                    "CATSfmPosHalfHeightOffset",
                |                    "CATSfmPosMidDistOffset",
                |                    "CATSfmPosMidDistMidDist",
                |                    "CATSfmPosHalfHeightMidDist"
                |             Please see CATIASfmPositioningStrategyManager
                |             
                |         iPositionStrategyParms
                |             [in ] List of Parameters for Positioning the Contour. See
                |             CATIASfmStandardPosStrategyParameters 
                |         ispTargetSfmObject
                |             [in ] Object on which Opening will be created 
                |         ospOpening
                |             [out] Created Opening 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This Creates Opening on the Plate using StandardOpening Mode.The
                |             Factory is retrieved from the Part
                | 
                |               'Get the Factory
                |               Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
                |               Dim StdOpening as SfmStandardOpening
                |               Set StdOpening = Factory.CreateStandardOpening("FunctionalOpening",
                |                                                              "Sfm_Rect",
                |                                                              oListCkeParms,
                |                                                              "CATSfmPosMidDistMidDist",
                |                                                              PositionStrategyParms,
                |                                                              plateref)

        :param str i_category:
        :param str i_contour_name:
        :param SFMStandardContourParameters i_list_contour_params:
        :param str i_pos_strategy_name:
        :param SFMStandardPosStrategyParameters i_position_strategy_parms:
        :param Reference isp_target_sfm_object:
        :rtype: SFMStandardOpening
        """
        return SFMStandardOpening(
            self.sfm_function_factory.CreateStandardOpening(
                i_category,
                i_contour_name,
                i_list_contour_params.com_object,
                i_pos_strategy_name,
                i_position_strategy_parms.com_object,
                isp_target_sfm_object.com_object
            )
        )

    def get_opening_mgr(self, i_prt_part: Part, i_mgr_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOpeningMgr(Part iPrtPart,
                | CATBSTR iMgrName) As CATBaseDispatch
                | 
                |     Gets the Opening Manager.Use this manager to get SfmOpeningContoursMgr or
                |     SfmPositioningStrategyManager. Use SfmOpeningContoursMgr to
                |     GetAvailableStdOpeningContours and GetStdOpeningContourParams Methods.See
                |     CATIASfmOpeningContoursMgr Use SfmPositioningStrategyManager to manage Position
                |     of contour.See CATIASfmPositioningStrategyManager
                | 
                |     Parameters:
                | 
                |         iPrtPart
                |             [in] Part which contains the plate on which opening is to be
                |             created. 
                |         iMgrName
                |             [in] SfmOpeningContoursMgr: Use to Get Contour Manager.
                |             SfmPositioningStrategyManager: Use to Get Position Strategy Manager
                |             
                |         oSfmOpeningMgr
                |             [out] Manager Object 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This Example gets the Manager from Factory.
                | 
                |               'Get the Factory
                |               Set Factory =  part1.GetCustomerFactory("SfmFunctionFactory")
                |               'Retrieve the Contour Manager
                |               Dim ObjSfmContourMgr As SfmOpeningContoursMgr
                |               Set ObjSfmContourMgr = Factory.GetOpeningMgr(Part1, "SfmOpeningContoursMgr")
                |               'Retrieve the Postion Strategy Manager
                |               Dim ObjSfmPosStrategyMgr  As
                |               SfmPositioningStrategyManager
                |               Set ObjSfmPosStrategyMgr = Factory.GetOpeningMgr(Part1, "SfmPositioningStrategyManager")

        :param Part i_prt_part:
        :param str i_mgr_name:
        :rtype: AnyObject
        """
        return self.sfm_function_factory.GetOpeningMgr(i_prt_part.com_object, i_mgr_name)

    def __repr__(self):
        return f'SFMFunctionFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class TextStream(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     TextStream
                | 
                | The textstream object allows to manage input and output for a text
                | stream.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.text_stream = com_object

    @property
    def at_end_of_line(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AtEndOfLine() As boolean (Read Only)
                | 
                |     Returns a boolean value which specifies if the index position in the stream
                |     is at a end of line.
                | 
                |     Example:
                |         This example retrieves in EndLine the end of line value for the
                |         TextStream TestStream.
                | 
                |          Dim EndLine As Boolean
                |          EndLine = TestStream.AtEndOfLine

        :rtype: bool
        """

        return self.text_stream.AtEndOfLine

    @property
    def at_end_of_stream(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AtEndOfStream() As boolean (Read Only)
                | 
                |     Returns a boolean value which specifies if the index position in the stream
                |     is at a end of stream.
                | 
                |     Example:
                |         This example retrieves in EndStream the end of stream value for the
                |         TextStream TestStream.
                | 
                |          Dim EndStream As Boolean
                |          EndStream = TestStream.AtEndOfStream

        :rtype: bool
        """

        return self.text_stream.AtEndOfStream

    def close(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Close()
                | 
                |     Closes a text stream.
                | 
                |     Example:
                |         This example closes the TextStream TestStream
                | 
                |          TestStream.Close

        :rtype: None
        """
        return self.text_stream.Close()

    def read(self, i_num_of_char: int) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Read(long iNumOfChar) As CATBSTR
                | 
                |     Returns a string which contains a given number of characters from the
                |     current position in the stream.
                | 
                |     Parameters:
                | 
                |         iNumOfChar
                |             The number of characters to read. 
                | 
                |     Returns:
                |         oReadString The retrieved string.
                | 
                |         Example:
                |             This example retrieves the next fifty characters of the TextStream
                |             TestStream in the stream ReadString.
                | 
                |              Dim ReadString As String
                |              Set ReadString = TestStream.Read(50)

        :param int i_num_of_char:
        :rtype: str
        """
        return self.text_stream.Read(i_num_of_char)

    def read_line(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func ReadLine() As CATBSTR
                | 
                |     Returns a string which contains a line of charaters from the current
                |     position in the stream.
                | 
                |     Returns:
                |         oReadLine The retrieved read line.
                | 
                |         Example:
                |             This example retrieves the next line of the TextStream TestStream
                |             in the stream ReadString.
                | 
                |              Dim ReadString As String
                |              Set ReadString = TestStream.ReadLine

        :rtype: str
        """
        return self.text_stream.ReadLine()

    def write(self, i_written_string: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Write(CATBSTR iWrittenString)
                | 
                |     Writes a string in the text stream.
                | 
                |     Parameters:
                | 
                |         iWrittenString
                |             The string to write in the stream.
                | 
                |             Example:
                |                 This example write a string in the the TextStream
                |                 TestStream.
                | 
                |                  TestStream.Write("This is a test")

        :param str i_written_string:
        :rtype: None
        """
        return self.text_stream.Write(i_written_string)

    def __repr__(self):
        return f'TextStream(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_machinable_feature import ManufacturingMachinableFeature
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class ManufacturingMachinableGeometry(ManufacturingMachinableFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    ManufacturingInterfaces.ManufacturingFeature
                |                        ManufacturingInterfaces.ManufacturingMachinableFeature
                |                             ManufacturingMachinableGeometry
                | 
                | Represents the machinable geometry object.
                | It is the low-level component of a machinable area.
                | 
                | See also:
                |     ManufacturingMachinableArea
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_machinable_geometry = com_object

    @property
    def shared(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Shared() As boolean
                | 
                |     Returns or sets the shared state of a ManufacturingMachinableGeometry
                |     object. 
                | Example:
                |     The following example returns in bState the shared state of manufacturing
                |     machinable geometry firstMachGeom and then sets it to
                |     TRUE:
                | 
                |      Dim firstMachGeom As ManufacturingMachinableGeometry
                |      Set firstMachGeom = ...
                |      Dim bState As boolean
                |      Set bState = firstMachGeom.Shared
                |      bState = TRUE
                |      firstMachGeom.Shared = bState

        :rtype: bool
        """

        return self.manufacturing_machinable_geometry.Shared

    @shared.setter
    def shared(self, value: bool):
        """
        :param bool value:
        """

        self.manufacturing_machinable_geometry.Shared = value

    def add_pointed_geometry(self, i_geometry: AnyObject, i_product: Product, i_shapes: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPointedGeometry(AnyObject iGeometry,
                | Product iProduct,
                | CATSafeArrayVariant iShapes)
                | 
                |     Adds a geometry to the pointed geometry list.
                | 
                |     Parameters:
                | 
                |         iGeometry
                |             The geometry to add 
                |         iProduct
                |             The product where the geometry to add is located 
                |         iShapes
                |             The list of shapes (body copied and pasted with links) where the
                |             geometry is to be added 
                | 
                |     Example:
                |         The following example adds the geometry GeomToAdd of the product
                |         ProdOfGeomToAdd to the pointed geometry list of the manufacturing machinable
                |         geometry firstMachGeom.
                | 
                |          Dim firstMachGeom As ManufacturingMachinableGeometry
                |          Set firstMachGeom = ...
                |          Dim GeomToAdd As Shape
                |          Dim ProdOfGeomToAdd As Product
                |          Set GeomToAdd = ...
                |          Set ProdOfGeomToAdd = ...
                |          Dim ShapesList() As Variant
                |          Redim ShapesList(0) ' Create an empty list of shapes
                |          Call firstMachGeom.AddPointedGeometry( GeomToAdd, ProdOfGeomToAdd,
                |          ShapesList )

        :param AnyObject i_geometry:
        :param Product i_product:
        :param tuple i_shapes:
        :rtype: cat_variant
        """
        return self.manufacturing_machinable_geometry.AddPointedGeometry(
            i_geometry.com_object,
            i_product.com_object,
            i_shapes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_pointed_geometry'
        # # vba_code = """
        # # Public Function add_pointed_geometry(manufacturing_machinable_geometry)
        # #     Dim iGeometry (2)
        # #     manufacturing_machinable_geometry.AddPointedGeometry iGeometry
        # #     add_pointed_geometry = iGeometry
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_pointed_geometry_notify(
            self,
            i_geometry: AnyObject,
            i_product: Product,
            i_shapes: tuple,
            i_notify: int
    ) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPointedGeometryNotify(AnyObject iGeometry,
                | Product iProduct,
                | CATSafeArrayVariant iShapes,
                | short iNotify)
                | 
                |     Adds a geometry to the pointed geometry list (manage
                |     notification).
                | 
                |     Parameters:
                | 
                |         iGeometry
                |             The geometry to add 
                |         iProduct
                |             The product where the geometry to add is located 
                |         iShapes
                |             The list of shapes (body copied and pasted with links) where the
                |             geometry is to be added 
                |         iNotify
                |             A flag to request whether to send a notification to update the
                |             model
                |             Legal values:
                |             0 No notification is sent and the model is not
                |             updated
                |             1 A notification is sent and the model is updated
                | 
                |     Example:
                |         The following example adds the geometry GeomToAdd of the product
                |         ProdOfGeomToAdd to the pointed geometry list of the manufacturing machinable
                |         geometry firstMachGeom.
                | 
                |          Dim firstMachGeom As ManufacturingMachinableGeometry
                |          Set firstMachGeom = ...
                |          Dim GeomToAdd As Shape
                |          Dim ProdOfGeomToAdd As Product
                |          Set GeomToAdd = ...
                |          Set ProdOfGeomToAdd = ...
                |          Dim ShapesList() As Variant
                |          Redim ShapesList(0) ' Create an empty list of shapes
                |          Call firstMachGeom.AddPointedGeometryNotify( GeomToAdd,
                |          ProdOfGeomToAdd, ShapesList, 0 )

        :param AnyObject i_geometry:
        :param Product i_product:
        :param tuple i_shapes:
        :param int i_notify:
        :rtype: cat_variant
        """
        return self.manufacturing_machinable_geometry.AddPointedGeometryNotify(
            i_geometry.com_object,
            i_product.com_object,
            i_shapes,
            i_notify
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_pointed_geometry_notify'
        # # vba_code = """
        # # Public Function add_pointed_geometry_notify(manufacturing_machinable_geometry)
        # #     Dim iGeometry (2)
        # #     manufacturing_machinable_geometry.AddPointedGeometryNotify iGeometry
        # #     add_pointed_geometry_notify = iGeometry
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_pointed_geometry_with_no_duplicated_check(
            self,
            i_geometry: AnyObject,
            i_product: Product,
            i_shapes: tuple
    ) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPointedGeometryWithNoDuplicatedCheck(AnyObject
                | iGeometry,
                | Product iProduct,
                | CATSafeArrayVariant iShapes)
                | 
                |     Adds a geometry to the pointed geometry list with no check on already
                |     referenced geometry.
                | 
                |     Parameters:
                | 
                |         iGeometry
                |             The geometry to add 
                |         iProduct
                |             The product where the geometry to add is located 
                |         iShapes
                |             The list of shapes (body copied and pasted with links) where the
                |             geometry is to be added 
                | 
                |     Example:
                |         The following example adds the geometry GeomToAdd of the product
                |         ProdOfGeomToAdd to the pointed geometry list of the manufacturing machinable
                |         geometry firstMachGeom.
                | 
                |          Dim firstMachGeom As ManufacturingMachinableGeometry
                |          Set firstMachGeom = ...
                |          Dim GeomToAdd As Shape
                |          Dim ProdOfGeomToAdd As Product
                |          Set GeomToAdd = ...
                |          Set ProdOfGeomToAdd = ...
                |          Dim ShapesList() As Variant
                |          Redim ShapesList(0) ' Create an empty list of shapes
                |          Call firstMachGeom.AddPointedGeometryWithNoDuplicatedCheck( GeomToAdd,
                |          ProdOfGeomToAdd, ShapesList )

        :param AnyObject i_geometry:
        :param Product i_product:
        :param tuple i_shapes:
        :rtype: cat_variant
        """
        return self.manufacturing_machinable_geometry.AddPointedGeometryWithNoDuplicatedCheck(i_geometry.com_object,
                                                                                              i_product.com_object,
                                                                                              i_shapes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_pointed_geometry_with_no_duplicated_check'
        # # vba_code = """
        # # Public Function add_pointed_geometry_with_no_duplicated_check(manufacturing_machinable_geometry)
        # #     Dim iGeometry (2)
        # #     manufacturing_machinable_geometry.AddPointedGeometryWithNoDuplicatedCheck iGeometry
        # #     add_pointed_geometry_with_no_duplicated_check = iGeometry
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_pointed_geometry_with_no_duplicated_check_notify(
            self,
            i_geometry: AnyObject,
            i_product: Product,
            i_shapes: tuple,
            i_notify: int
    ) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPointedGeometryWithNoDuplicatedCheckNotify(AnyObject
                | iGeometry,
                | Product iProduct,
                | CATSafeArrayVariant iShapes,
                | short iNotify)
                | 
                |     Adds a geometry to the pointed geometry list with no check on an already
                |     referenced geometry.
                | 
                |     Parameters:
                | 
                |         iGeometry
                |             The geometry to add 
                |         iProduct
                |             The product where the geometry to add is located 
                |         iShapes
                |             The list of shapes (body copied and pasted with links) where the
                |             geometry is to be added 
                |         iNotify
                |             A flag to request whether to send a notification to update the
                |             model
                |             Legal values:
                |             0 No notification is sent and the model is not
                |             updated
                |             1 A notification is sent and the model is updated
                | 
                |     Example:
                |         The following example adds the geometry GeomToAdd of the product
                |         ProdOfGeomToAdd to the pointed geometry list of the manufacturing machinable
                |         geometry firstMachGeom:
                | 
                |          Dim firstMachGeom As ManufacturingMachinableGeometry
                |          Set firstMachGeom = ...
                |          Dim GeomToAdd As Shape
                |          Dim ProdOfGeomToAdd As Product
                |          Set GeomToAdd = ...
                |          Set ProdOfGeomToAdd = ...
                |          Dim ShapesList() As Variant
                |          Redim ShapesList(0) ' Create an empty list of shapes
                |          Call firstMachGeom.AddPointedGeometryWithNoDuplicatedCheckNotify(
                |          GeomToAdd, ProdOfGeomToAdd, ShapesList, 0 )

        :param AnyObject i_geometry:
        :param Product i_product:
        :param tuple i_shapes:
        :param int i_notify:
        :rtype: cat_variant
        """
        return self.manufacturing_machinable_geometry.AddPointedGeometryWithNoDuplicatedCheckNotify(
            i_geometry.com_object,
            i_product.com_object,
            i_shapes,
            i_notify
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_pointed_geometry_with_no_duplicated_check_notify'
        # # vba_code = """
        # # Public Function add_pointed_geometry_with_no_duplicated_check_notify(manufacturing_machinable_geometry)
        # #     Dim iGeometry (2)
        # #     manufacturing_machinable_geometry.AddPointedGeometryWithNoDuplicatedCheckNotify iGeometry
        # #     add_pointed_geometry_with_no_duplicated_check_notify = iGeometry
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_associated_tps(self, index_of_pointed_geom: int, o_annotations_list: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAssociatedTPS(long IndexOfPointedGeom,
                | CATSafeArrayVariant oAnnotationsList)
                |
                |     Retrieves the Annotation object lists associated with a
                |     ManufacturingMachinableGeometry object.
                |
                |     Parameters:
                |
                |         IndexOfPointedGeom
                |             The index of the pointed geometry among those associated with the
                |             ManufacturingMachinableGeometry object
                |         oAnnotationsList
                |             The retrieved list Annotation objects.
                |             The array must be previously initialized using the
                |
                |
                |         GetAssociatedTPSCount method.
                |
                | Example:
                |     The following example retrieves the Annotation object list of the third
                |     pointed geometry under the manufacturing machinable geometry firstMachGeom in
                |     AnnotationList:
                |
                |      Dim firstMachGeom As ManufacturingMachinableGeometry
                |      Set firstMachGeom = ...
                |      Dim AssociatedTPSCount As Long
                |      AssociatedTPSCount = firstMachGeom.GetAssociatedTPSCount (2)
                |      If (AssociatedTPSCount > 0) Then
                |        Dim I As Long
                |
                |        Dim AnnotationList() As Variant
                |        Redim AnnotationList(AssociatedTPSCount-1)
                |        Call firstMachGeom.GetAssociatedTPS(2, AnnotationList)
                |
                |      End If

        :param int index_of_pointed_geom:
        :param tuple o_annotations_list:
        :rtype: Variant
        """
        return self.manufacturing_machinable_geometry.GetAssociatedTPS(
            index_of_pointed_geom,
            o_annotations_list
        )
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_associated_tps'
        # # vba_code = """
        # # Public Function get_associated_tps(manufacturing_machinable_geometry)
        # #     Dim IndexOfPointedGeom (2)
        # #     manufacturing_machinable_geometry.GetAssociatedTPS IndexOfPointedGeom
        # #     get_associated_tps = IndexOfPointedGeom
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_associated_tps_count(self, index_of_pointed_geom: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAssociatedTPSCount(long IndexOfPointedGeom) As
                | long
                |
                |     Returns the number of Annotation objects attached to a pointed geometry
                |     under a ManufacturingMachinableGeometry object.
                |
                |     Parameters:
                |
                |         IndexOfPointedGeom
                |             The index of the pointed geometry
                |             Note: Check that the index you are passing in less than or equal to
                |             the pointed geometry count retrieved using the
                |
                |         PointedGeometryCount method.
                |     oAnnotationsListCount
                |         The number of Annotation objects
                |
                | Example:
                |     The following example retrieves the number of Annotation objects attached
                |     to the third geometry under the manufacturing machinable geometry firstMachGeom
                |     in AssociatedTPSCount:
                |
                |      Dim firstMachGeom As ManufacturingMachinableGeometry
                |      Set firstMachGeom = ...
                |      Dim AssociatedTPSCount As Long
                |      AssociatedTPSCount = PointedGeometryListSize = firstMachGeom.GetAssociatedTPSCount( 3 )

        :param int index_of_pointed_geom:
        :rtype: int
        """
        return self.manufacturing_machinable_geometry.GetAssociatedTPSCount(index_of_pointed_geom)

    def get_direction(self, o_x: float, o_y: float, o_z: float, index_of_pointed_geom: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDirection(double oX,
                | double oY,
                | double oZ,
                | long IndexOfPointedGeom)
                |
                |     Retrieves the direction of a pointed geometry under a
                |     ManufacturingMachinableGeometry object.
                |     Note: Currently valid only for AxialUDF and DesignHole
                |     features.
                |
                |     Parameters:
                |
                |         oX,oY,oZ
                |             The components of the direction
                |         IndexOfPointedGeom
                |             The index of the pointed geometry
                |             Note: Check that the index you are passing in less than or equal to
                |             the pointed geometry count retrieved using the
                |
                |         PointedGeometryCount method.
                |
                | Example:
                |     The following example retrieves the components of the direction of the
                |     third geometry under the manufacturing machinable geometry
                |     firstMachGeom:
                |
                |      Dim firstMachGeom As ManufacturingMachinableGeometry
                |      Set firstMachGeom = ...
                |      Dim oX As Double
                |      Dim oY As Double
                |      Dim oZ As Double
                |      Call firstMachGeom.GetDirection( oX, oY, oZ, 3)

        :param float o_x:
        :param float o_y:
        :param float o_z:
        :param int index_of_pointed_geom:
        :rtype: None
        """
        return self.manufacturing_machinable_geometry.GetDirection(o_x, o_y, o_z, index_of_pointed_geom)

    def get_origin(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOrigin(double oX,
                | double oY,
                | double oZ,
                | long IndexOfPointedGeom)
                |
                |     Retrieves the origin of a pointed geometry under a
                |     ManufacturingMachinableGeometry object.
                |     Note: Currently valid only for AxialUDF and DesignHole
                |     features.
                |
                |     Parameters:
                |
                |         oX,oY,oZ
                |             The coordinates of the origin
                |         IndexOfPointedGeom
                |             The index of the pointed geometry
                |             Note: Check that the index you are passing in less than or equal to
                |             the pointed geometry count retrieved using the
                |
                |         PointedGeometryCount method.
                |
                | Example:
                |     The following example retrieves the coordinates of the origin of the third
                |     geometry under the manufacturing machinable geometry
                |     firstMachGeom:
                |
                |      Dim firstMachGeom As ManufacturingMachinableGeometry
                |      Set firstMachGeom = ...
                |      Dim oX As Double
                |      Dim oY As Double
                |      Dim oZ As Double
                |      Call firstMachGeom.GetOrigin( oX, oY, oZ, 3)

        :rtype: tuple
        """
        return self.manufacturing_machinable_geometry.GetOrigin()

    def list_pointed_geometry(
            self,
            i_index: int,
            o_geometry: AnyObject,
            o_product: Product,
            o_nb_shapes: int
    ) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListPointedGeometry(long iIndex,
                | AnyObject oGeometry,
                | Product oProduct,
                | long oNbShapes)
                |
                |     Retrieves a pointed geometry and its product.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the pointed geometry and product
                |         oGeometry
                |             The retrieved geometry
                |         oProduct
                |             The product of the retrieved geometry
                |         oNbShapes
                |             The number of shapes of the retrieved geometry
                |
                |     Example:
                |         The following example retrieves the pointed geometry lists of the
                |         manufacturing machinable geometry firstMachGeom in PointedGeometryList and in
                |         PointedProductsList. The arrays must be previously initialized using the
                |
                |
                |     PointedGeometryCount method.
                |
                |      Dim firstMachGeom As ManufacturingMachinableGeometry
                |      Set firstMachGeom = ...
                |      Dim PointedGeometryListSize As Long
                |      Set PointedGeometryListSize = firstMachGeom.PointedGeometryCount
                |      If (PointedGeometryListSize > 0) Then
                |        Dim I As Long
                |        For I = 0 To PointedGeometryListSize-1
                |          Dim PointedGeometryList() As Variant
                |          Dim PointedProductsList() As Variant
                |          Dim NbShapes As Long
                |          Redim PointedGeometryList(PointedGeometryListSize-1)
                |          Redim PointedProductsList(PointedGeometryListSize-1)
                |          Call firstMachGeom.ListPointedGeometry(I, PointedGeometryList,
                |          PointedProductsList, NbShapes)
                |        End For
                |      End If

        :param int i_index:
        :param AnyObject o_geometry:
        :param Product o_product:
        :param int o_nb_shapes:
        :rtype: cat_variant
        """
        return self.manufacturing_machinable_geometry.ListPointedGeometry(
            i_index,
            o_geometry.com_object,
            o_product.com_object,
            o_nb_shapes
        )
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_pointed_geometry'
        # # vba_code = """
        # # Public Function list_pointed_geometry(manufacturing_machinable_geometry)
        # #     Dim iIndex (2)
        # #     manufacturing_machinable_geometry.ListPointedGeometry iIndex
        # #     list_pointed_geometry = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_shapes_of_pointed_geometry(self, i_index: int, o_shapes: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListShapesOfPointedGeometry(long iIndex,
                | CATSafeArrayVariant oShapes)
                |
                |     Retrieves the pointed shape list.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the pointed geometry and product
                |         oShapes
                |             The retrieved shape list.
                |             The array must be previously initialized using the
                |
                |
                |         ListPointedGeometry method.
                |
                | Example:
                |     The following example retrieves the pointed shape list of the manufacturing
                |     machinable geometry firstMachGeom in PointedShapesList.
                |
                |      Dim firstMachGeom As ManufacturingMachinableGeometry
                |      Set firstMachGeom = ...
                |      Dim PointedGeometryListSize As Long
                |      Set PointedGeometryListSize = firstMachGeom.PointedGeometryCount
                |      If (PointedGeometryListSize > 0) Then
                |        Dim I As Long
                |        For I = 0 To PointedGeometryListSize-1
                |          Dim PointedGeometryList() As Variant
                |          Dim PointedProductsList() As Variant
                |          Dim NbShapes As Long
                |          Redim PointedGeometryList(PointedGeometryListSize-1)
                |          Redim PointedProductsList(PointedGeometryListSize-1)
                |          Call firstMachGeom.ListPointedGeometry(I, PointedGeometryList,
                |          PointedProductsList, NbShapes)
                |          If (NbShapes > 0) Then
                |            Dim PointedShapesList() As Variant
                |            Redim PointedShapesList(NbShapes-1)
                |            Call firstMachGeom.ListShapesOfPointedGeometry(I,
                |            PointedShapesList)
                |          End If
                |        End For
                |      End If

        :param int i_index:
        :param tuple o_shapes:
        :rtype: Variant
        """
        return self.manufacturing_machinable_geometry.ListShapesOfPointedGeometry(i_index, o_shapes)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_shapes_of_pointed_geometry'
        # # vba_code = """
        # # Public Function list_shapes_of_pointed_geometry(manufacturing_machinable_geometry)
        # #     Dim iIndex (2)
        # #     manufacturing_machinable_geometry.ListShapesOfPointedGeometry iIndex
        # #     list_shapes_of_pointed_geometry = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def pointed_geometry_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func PointedGeometryCount() As long
                |
                |     Returns the pointed geometry list count.
                |
                | Example:
                |     The following example retrieves the pointed geometry list count of the
                |     manufacturing machinable geometry firstMachGeom in
                |     PointedGeometryListSize.
                |
                |      Dim firstMachGeom As ManufacturingMachinableGeometry
                |      Set firstMachGeom = ...
                |      Dim PointedGeometryListSize As Long
                |      Set PointedGeometryListSize = firstMachGeom.PointedGeometryCount

        :rtype: int
        """
        return self.manufacturing_machinable_geometry.PointedGeometryCount()

    def remove_pointed_geometry(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePointedGeometry(long iIndex)
                |
                |     Removes a geometry from the pointed geometry list.
                |
                |     Parameters:
                |
                |         iIndex
                |             The index of the geometry to remove
                |
                |     Example:
                |         The following example removes the third geometry from the pointed
                |         geometry list of the manufacturing machinable geometry
                |         firstMachGeom:
                |
                |          Dim firstMachGeom As ManufacturingMachinableGeometry
                |          Set firstMachGeom = ...
                |          Call firstMachGeom.RemovePointedGeometry( 3 )

        :param int i_index:
        :rtype: None
        """
        return self.manufacturing_machinable_geometry.RemovePointedGeometry(i_index)

    def __repr__(self):
        return f'ManufacturingMachinableGeometry(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.system_interfaces.any_object import AnyObject


class DeviceTask(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DeviceTask
                | 
                | Represents the Device Task.
                | 
                | Role: The interface is used manage activities under a Device
                | Task.
                | The following code snippet can be used to obtain the Device Task from a Device
                | Task Factory.
                | 
                |    Dim objDeviceTaskFactory As DeviceTaskFactory
                |    Dim objDevice As Product
                |    ...
                |    Set objDeviceTaskFactory = objDevice.GetTechnologicalObject("DeviceTaskFactory" )
                |    Dim objDeviceTaskList(3) as DeviceTask
                |    Dim objDeviceTask as DeviceTask
                |    objDeviceTaskFactory.GetAllDeviceTasks objDeviceTaskList
                |    objDeviceTask=objDeviceTaskList[0]
                |  
                | 
                | 
                | The Device Task can also be obtained from an activity of the type
                | DeviceTask.
                | 
                |    Dim objActivity as Activity
                |    ...
                |    Dim objDeviceTask as DeviceTask
                |    Set objDeviceTask = objActivity.GetTechnologicalObject("DeviceTask" )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.device_task = com_object

    def create_delay_activity(
            self,
            isp_father: AnyObject,
            position: int,
            delay_time: float,
            o_delay_acty: Activity
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateDelayActivity(AnyObject ispFather,
                | short position,
                | double delay_time,
                | Activity oDelayActy)
                | 
                |     Creates a Delay Activity inside a Device Task
                | 
                |     Parameters:
                | 
                |         ispFather
                |             The Activity preceeding the new activity. 
                |         position
                |             Whether to insert activity before or after father. 0 tells at the
                |             start and 1 means after 
                |         delay_time
                |             The input delay time value to be set. 
                |         oDelayActy
                |             The created Delay Activity 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Delay Activity was successfully created.
                |         E_FAIL
                |             The Delay Activity could not be created.
                | 
                |         Example:
                |             The following example creates An Delay Activity under a given
                |             device task
                | 
                |                Dim objDeviceTask as DeviceTask
                |                Dim objPreceedingActy as Activity
                |                ..
                |                Dim objDelayAct as Object
                |                objDeviceTask.CreateDelayActivity
                |                objPreceedingActy,1,objDelayAct

        :param AnyObject isp_father:
        :param int position:
        :param float delay_time:
        :param Activity o_delay_acty:
        :rtype: None
        """
        return self.device_task.CreateDelayActivity(
            isp_father.com_object,
            position,
            delay_time,
            o_delay_acty.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_delay_activity'
        # # vba_code = """
        # # Public Function create_delay_activity(device_task)
        # #     Dim ispFather (2)
        # #     device_task.CreateDelayActivity ispFather
        # #     create_delay_activity = ispFather
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_move_home_activity(self, isp_father: AnyObject, position: int, o_move_home_acty: Activity) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateMoveHomeActivity(AnyObject ispFather,
                | short position,
                | Activity oMoveHomeActy)
                | 
                |     Creates a MoveHome Activity inside a Device Task
                | 
                |     Parameters:
                | 
                |         ispFather
                |             The Activity preceeding the new activity. 
                |         position
                |             Whether to insert activity before or after father. 0 tells at the
                |             start and 1 means after 
                |         oMoveHomeActy
                |             The created MoveHome Activity 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The MoveHome Activity was successfully created.
                |         E_FAIL
                |             The MoveHome Activity could not be created.
                | 
                |         Example:
                |             The following example creates An MoveHome Activity under a given
                |             device task
                | 
                |                Dim objDeviceTask as DeviceTask
                |                Dim objPreceedingActy as Activity
                |                ..
                |                Dim objMovHomeAct as Object
                |                objDeviceTask.CreateMoveHomeActivity
                |                objPreceedingActy,1,objMovHomeAct

        :param AnyObject isp_father:
        :param int position:
        :param Activity o_move_home_acty:
        :rtype: None
        """
        return self.device_task.CreateMoveHomeActivity(isp_father.com_object, position, o_move_home_acty.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_move_home_activity'
        # # vba_code = """
        # # Public Function create_move_home_activity(device_task)
        # #     Dim ispFather (2)
        # #     device_task.CreateMoveHomeActivity ispFather
        # #     create_move_home_activity = ispFather
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_move_joints_activity(self, isp_father: AnyObject, position: int, o_move_joints_acty: Activity) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateMoveJointsActivity(AnyObject ispFather,
                | short position,
                | Activity oMoveJointsActy)
                | 
                |     Creates a MoveJoints Activity inside a Device Task
                | 
                |     Parameters:
                | 
                |         ispFather
                |             The Activity preceeding the new activity. 
                |         position
                |             Whether to insert activity before or after father. 0 tells at the
                |             start and 1 means after 
                |         oMoveJointsActy
                |             The created MoveJoints Activity 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The MoveJoints Activity was successfully created.
                |         E_FAIL
                |             The MoveJoints Activity could not be created.
                | 
                |         Example:
                |             The following example creates An MoveJoints Activity under a given
                |             device task
                | 
                |                Dim objDeviceTask as DeviceTask
                |                Dim objPreceedingActy as Activity
                |                ..
                |                Dim objMovJointsAct as Object
                |                objDeviceTask.CreateMoveJointsActivity
                |                objPreceedingActy,1,objMovJointsAct

        :param AnyObject isp_father:
        :param int position:
        :param Activity o_move_joints_acty:
        :rtype: None
        """
        return self.device_task.CreateMoveJointsActivity(isp_father.com_object, position, o_move_joints_acty.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_move_joints_activity'
        # # vba_code = """
        # # Public Function create_move_joints_activity(device_task)
        # #     Dim ispFather (2)
        # #     device_task.CreateMoveJointsActivity ispFather
        # #     create_move_joints_activity = ispFather
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DeviceTask(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.basic_component import BasicComponent
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class BasicComponents(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     BasicComponents
                | 
                | The collection of Basic Components defining and analysis
                | object.
                | These components are agregated by another basic component, an entity or a
                | set.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=BasicComponent)
        self.basic_components = com_object

    def item(self, i_variant: cat_variant) -> BasicComponent:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iVariant) As BasicComponent
                | 
                |     Returns an Basic Component using its index or its name from the Basic
                |     Components collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Basic Component to retrieve from the
                |             collection of Basic Component. As a numerics, this index is the rank of the
                |             Basic Component. in the collection. The index of the first Basic Component in
                |             the collection is 1, and the index of the last Basic Component is Count. As a
                |             string, it is the name you assigned to the Basic Component using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved Basic Component

        :param cat_variant i_variant:
        :rtype: BasicComponent
        """
        return BasicComponent(self.basic_components.Item(i_variant))

    def __repr__(self):
        return f'BasicComponents(name="{self.name}")'
